@@ -231,6 +231,11 @@ extern "C" {
   /*#define NCO_HSH_TRV_OBJ */
 #undef NCO_HSH_TRV_OBJ
 
+  /* 20240927: netCDF 4.9.3 switched "_FillValue" to NC_FillValue macro */
+#ifndef NC_FillValue
+# define NC_FillValue      "_FillValue"
+#endif /* !NC_FillValue */
+
   /* NCO_MSS_VAL_SNG names attribute whose value is "skipped" by arithmetic, aka the missing value attribute
      Attribute name should be either "missing_value" or "_FillValue" */
 #ifndef NCO_MSS_VAL_SNG
@@ -311,11 +316,13 @@ extern "C" {
 
 # ifdef NCO_USE_FILL_VALUE
   /* This arcane get()/set() usage necessary because TKN2SNG() macro above is broken. TODO nco905 */
-  char nco_mss_val_sng[]="_FillValue"; /* [sng] Missing value attribute name */
+  //  char nco_mss_val_sng[]="_FillValue"; /* [sng] Missing value attribute name */
+  char nco_mss_val_sng[]=NC_FillValue; /* [sng] Missing value attribute name */
   char nco_not_mss_val_sng[]="missing_value"; /* [sng] Not missing value attribute name */
 # else /* !NCO_USE_FILL_VALUE */
   char nco_mss_val_sng[]="missing_value"; /* [sng] Missing value attribute name */
-  char nco_not_mss_val_sng[]="_FillValue"; /* [sng] Not missing value attribute name */
+  //  char nco_not_mss_val_sng[]="_FillValue"; /* [sng] Not missing value attribute name */
+  char nco_not_mss_val_sng[]=NC_FillValue; /* [sng] Not missing value attribute name */
 # endif /* !NCO_USE_FILL_VALUE */
   char *nco_mss_val_sng_get(void){return nco_mss_val_sng;} /* [sng] Missing value attribute name */
   char *nco_not_mss_val_sng_get(void){return nco_not_mss_val_sng;} /* [sng] Not missing value attribute name */
@@ -370,10 +377,10 @@ extern "C" {
 # define NCO_VERSION_MAJOR 5
 #endif /* !NCO_VERSION_MAJOR */
 #ifndef NCO_VERSION_MINOR
-# define NCO_VERSION_MINOR 2
+# define NCO_VERSION_MINOR 3
 #endif /* !NCO_VERSION_MINOR */
 #ifndef NCO_VERSION_PATCH
-# define NCO_VERSION_PATCH 6
+# define NCO_VERSION_PATCH 1
 #endif /* !NCO_VERSION_PATCH */
 #ifndef NCO_VERSION_NOTE
 # define NCO_VERSION_NOTE "" /* Blank for final versions, non-blank (e.g., "-beta73") for pre-release versions */
@@ -383,7 +390,7 @@ extern "C" {
 # define NCO_LIB_VERSION ( NCO_VERSION_MAJOR * 100 + NCO_VERSION_MINOR * 10 + NCO_VERSION_PATCH )
 #endif /* !NCO_LIB_VERSION */
 #ifndef NCO_VERSION
-# define NCO_VERSION "5.2.6"
+# define NCO_VERSION "5.3.2"
 #endif /* !NCO_VERSION */
 
 /* Compatibility tokens new to netCDF4 netcdf.h: */
@@ -844,7 +851,7 @@ extern "C" {
     typ_sym, /* [enm] Symbol identifier */
     typ_opr /* [enm] Operator */
   } nod_typ_enm; /* end Node enumerator */
-  /* end enumeration section */
+  /* !enumeration section */
 
   typedef enum { /* [enm] Calendar type */
     cln_std=1, /* Standard mixed Julian/Gregorian */
@@ -1141,7 +1148,7 @@ extern "C" {
     nco_wgt_bln  /* Bilinear interpolation */
   } nco_wgt_typ_enm;
 
-typedef enum nco_xtr_typ_enm
+  typedef enum nco_xtr_typ_enm
     { /* [enm] Extrapolation type enum */
      nco_xtr_fll_lnr=0, // Perform linear extrapolation using two nearest valid neighbors
      nco_xtr_fll_ngh, // Set extrapolated value to value of nearest valid neighbor
@@ -1181,6 +1188,7 @@ typedef enum nco_xtr_typ_enm
     char *fl_out; /* [sng] File containing regridded fields */
     char *fl_out_tmp; /* [sng] Temporary file containing regridded fields */
     char *fl_map; /* [sng] File containing mapping weights from source to destination grid */
+    char *fl_nlm; /* [sng] File containing nonlinear mapping weights from source to destination grid */
     char *fl_vrt_in; /* [sng] File containing input vertical coordinate grid */
     char *fl_vrt_out; /* [sng] File containing output vertical coordinate grid */
     char *fl_msh;  /* [sng] File that contains SCRIP formatted overlap mesh */
@@ -1243,13 +1251,14 @@ typedef enum nco_xtr_typ_enm
     long lat_nbr; /* [nbr] Number of latitudes in destination grid */
     long lon_nbr; /* [nbr] Number of longitudes in destination grid */
     long xtr_nsp; /* [nbr] Extrapolation number of source points */
+    nco_edg_typ_enm edg_typ; /* [enm] Arc-type for triangle edges */
     nco_grd_2D_typ_enm grd_typ; /* [enm] Destination grid-type enum */
     nco_grd_lat_drc_enm lat_drc; /* [enm] Latitude grid-direction enum */
     nco_grd_lat_typ_enm lat_typ; /* [enm] Latitude grid-type enum */
     nco_grd_lon_typ_enm lon_typ; /* [enm] Longitude grid-type enum */
+    int lut_out; /* [enm] Landunit type(s) for S1D column output */
     nco_ntp_typ_enm ntp_mth; /* [enm] Interpolation method */
     nco_ply_tri_mth_typ_enm ply_tri_mth; /* [enm] Polygon-to-triangle decomposition method */ 
-    nco_edg_typ_enm edg_typ; /* [enm] Arc-type for triangle edges */
     nco_xtr_typ_enm xtr_mth; /* [enm] Extrapolation method */
     nco_wgt_typ_enm wgt_typ; /* [enm] Weight generation type */
     // Other internal data and metadata 
@@ -1263,7 +1272,7 @@ typedef enum nco_xtr_typ_enm
     int rgr_nbr; /* [nbr] Number of regridding arguments */
     int thr_nbr; /* [nbr] Thread number */
     int xtn_nbr; /* [nbr] Number of extensive variables */
-    int area_mth; /* [enm]  area method used calculating grid cell area */
+    int area_mth; /* [enm] Method to calculate gridcell area */
     long idx_dbg; /* [idx] Index of gridcell for debugging */
     long tst; /* [enm] Generic key for testing (undocumented) */
     nco_bool flg_add_fll; /* [flg] Add _FillValue to fields with empty destination cells */
@@ -1277,13 +1286,14 @@ typedef enum nco_xtr_typ_enm
     nco_bool flg_grd; /* [flg] Create SCRIP-format grid file */
     nco_bool flg_grd_dst; /* [flg] User-specified destination grid */
     nco_bool flg_grd_src; /* [flg] User-specified input grid */
-    nco_bool flg_mpt_mss; /* [flg] Set empty (sgs_frc=0.0) SGS cells to missing value */
+    nco_bool flg_mpt_mss; /* [flg] Set empty (sgs_frc==0.0) SGS cells to missing value */
     nco_bool flg_msk_apl; /* [flg] Apply msk_out to variables after regridding */
     nco_bool flg_msk_out; /* [flg] Add mask to output */
     nco_bool flg_nfr; /* [flg] Infer SCRIP-format grid file */
     nco_bool flg_ps_rtn; /* [flg] Retain surface pressure variable in vertical interpolation output */
     nco_bool flg_rnr; /* [flg] Renormalize destination values by valid area */
-    nco_bool flg_s1d; /* [flg] Unpack sparse-1D CLM/ELM variables */
+    nco_bool flg_s1d; /* [flg] Unpack sparse-1D (S1D) CLM/ELM variables */
+    nco_bool flg_snw_ocn; /* [flg] Unpack S1D snow fields into sane (ocean-like) level order */
     nco_bool flg_stg; /* [flg] Write staggered grid with FV output */
     nco_bool flg_uio; /* [flg] Unbuffered I/O (NC_SHARE) for netCDF3 files */
     nco_bool flg_usr_rqs; /* [flg] User-requested regridding */
