@@ -20,7 +20,7 @@
 /* Standard header files */
 #include <ctype.h> /* isalnum(), isdigit(), tolower() */
 #include <stdio.h> /* stderr, FILE, NULL, printf */
-#include <stdlib.h> /* strtod, strtol, malloc, getopt, exit */
+#include <stdlib.h> /* strtod, strtol, malloc, getopt, exit, mkstemp */
 #include <string.h> /* strcmp() */
 #ifdef HAVE_STRINGS_H
 # include <strings.h> /* strcasecmp() */
@@ -48,7 +48,7 @@
 
 #ifdef __cplusplus
 extern "C" {
-#endif /* __cplusplus */
+#endif /* !__cplusplus */
 
   /* Calendar types */
   typedef enum {
@@ -211,7 +211,7 @@ extern "C" {
 #endif /* !ENABLE_UDUNITS */
 
 #ifdef __cplusplus
-} /* end extern "C" */
-#endif /* __cplusplus */
+} /* !extern "C" */
+#endif /* !__cplusplus */
 
-#endif /* NCO_CLN_UTL_H */
+#endif /* !NCO_CLN_UTL_H */
